/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. You may use this
    software and any derivatives exclusively with Microchip products.

    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY IMPLIED
    WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
    PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP PRODUCTS, COMBINATION
    WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.

    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
    BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE
    FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN
    ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY,
    THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.

    MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE
    TERMS.
*/

/* 
 * File:   system_properties.h
 * Author: M91406
 * Comments: 
 *	in this file basic parameters like LED forward current or output voltage clamping
 *	are set and and conversion macros are provided to determine the correct register
 *   values
 * Revision history: 
 *   01/13/2016:	v1.0, initial version
 */

// This is a guard condition so that contents of this file are not included
// more than once.  
#ifndef SYSTEM_PROPERTIES_H
#define	SYSTEM_PROPERTIES_H

#include <xc.h>		// include processor files - each processor file is guarded.  
#include <stdint.h>	// include standard integer types

// ======================================================================================================
// Basic operating settings
// ======================================================================================================
#ifndef __DEBUG
#define USE_DEBUG_PIN				0			// Flag indicating if task activity should be shown via RA2
#else
#define USE_DEBUG_PIN				0			// Flag indicating if task activity should be shown via RA2
#endif

#define USE_SOFTSTART				0			// Flag indicating if soft-start ramp should be generated
#define USE_BINNING					0			// Flag to enable/disable spread spectrum modulation
#define USE_SPREAD_SPECTRUM			0			// Flag to enable/disable spread spectrum modulation 

#define USE_ANIMATION				0			// Flag to enable animated dimming pattern

// ======================================================================================================
// Basic operating settings
// ======================================================================================================

#define DimmFrequency				1000		// Desired dimming frequency in Hz
#define LEDForwardCurrent			350			// Desired LED forward current in mA

#define OutputVoltageClamping		50.0		// Desired Output Over Voltage Clamping in V
#define OutputVoltageClampRecovery	48.0		// Desired Output Over Voltage Clamping Recovery Threshold in V
#define InputUVLOTrip				6.0			// Desired Input Under Voltage Lockout Threshold in V
#define InputUVLORecovery			7.5			// Desired Input Under Voltage Lockout Recovery Threshold in V
#define InputOVLOTrip				24  		// Desired Input Over Voltage Lockout Threshold in V
#define InputOVLORecovery			23  		// Desired Input Over Voltage Lockout Recovery Threshold in V

#define LED_OTWTrip					100			// Desired Over Temperature Warning Threshold in C
#define LED_OTWRecovery				90			// Desired Over Temperature Warning Recovery Threshold in C
#define LED_OTPTrip					124			// Desired Over Temperature Protection Threshold in C
#define LED_OTPRecovery				90			// Desired Over Temperature Protection Recovery Threshold in C

#define PowerOnDelay				100			// Desired Power Up Delay in FaultHandlerLoops

// ======================================================================================================
// Conversion factors and macros 
// ======================================================================================================

#define DACREF2IfwdScaler			8.000		// Scaling factor of 10-bit DAC value to LED forward
												// current with 0.250 Ohm shunt resistor and 10-bit DAC
												// with FVR = 2.048V as reference in [mA/tick]

#define ADC2VinScaler				0.0449658	// Scaling factor of 10-bit ADC value to input voltage
												// for input voltage divider 82k/10k and 10-bit ADC
												// with VDD as reference in [V/tick]
                                                //(10/92)*1023/5=22.246; 1/22.24=0.045  <---------------------
                                                //(5/1023)*69/10  <---------------------

#define ADC2VoutScaler				0.1263367	// Scaling factor of 10-bit ADC value to output voltage
												// for output voltage divider 82k/3k3 and 10-bit ADC
												// with VDD as reference in [V/tick]

#define DACREF2VoutScaler			4.038836		// Scaling factor of 5-bit DAC value to output voltage
												// for output voltage divider 82k/3k3 and 5-bit DAC
												// with VDD as reference in [V/tick]
                                                //(3.3/85.3)*32/5=0.248; 1/0.248=4.04  <---------------------
                                                //(5/32)*85.3/3.3  <---------------------

#define ADC2TempScaler				1.0			// Scaling factor of 10-bit ADC value to LED load NTC
												// feedback voltage for 10k reference resistor over 10k 
												// NTC

// Conversion Macros => all DAC, ADC and period values are right justified
// TODO: Not all variables have been transfered into macros yet. Some still have to be set as pure 
// register values manually

#define tBlankingF					0
#define tBlankingR					0

#define tCCP1DutyCycleClamping		0x29		// Value for max. duty cycle @ switching frequency


#define dimmfrequencyticks			(((uint16_t)(16000000/DimmFrequency))-1)		// FOSC / f_DIMM

#define SchedulerTaskSlot			((uint8_t)(16000000/16/SchedulerFrequency))	// FOSC / f_sched

#define SlopeValue					0          //PRG Slopecompensation value


#define nominalLEDCurrent			((uint16_t)(LEDForwardCurrent/DACREF2IfwdScaler))
#define startupLEDCurrent			((uint16_t)(LEDForwardCurrentStartup/DACREF2IfwdScaler))

#define fltUVLOTrip					((uint16_t)(InputUVLOTrip/ADC2VinScaler))
#define fltUVLORelease				((uint16_t)(InputUVLORecovery/ADC2VinScaler))
#define fltOVLOTrip					((uint16_t)(InputOVLOTrip/ADC2VinScaler))
#define fltOVLORelease				((uint16_t)(InputOVLORecovery/ADC2VinScaler))
#define fltOTWTrip					((uint16_t)(LED_OTWTrip/ADC2TempScaler))
#define fltOTWRelease				((uint16_t)(LED_OTWRecovery/ADC2TempScaler))
#define fltOTPTrip					((uint16_t)(LED_OTPTrip/ADC2TempScaler))
#define fltOTPRelease				((uint16_t)(LED_OTPRecovery/ADC2TempScaler))
#define fltOVPTrip					((uint16_t)(OutputVoltageClamping/ADC2VoutScaler))
#define fltOVPRelease				((uint16_t)(OutputVoltageClampRecovery/ADC2VoutScaler))

#define fltUVLOCounterThshld		3		// n successive "Out-Of-Range" samples required to trip fault
#define fltOVLOCounterThshld		3		// n successive "Out-Of-Range" samples required to trip fault
#define fltOVPCounterThshld			3		// n successive "Out-Of-Range" samples required to trip fault
#define fltOTWCounterThshld			100		// n successive "Out-Of-Range" samples required to trip fault
#define fltOTPCounterThshld			100		// n successive "Out-Of-Range" samples required to trip fault
#define fltRecoveryCounterThshld	PowerOnDelay		// n successive "In-Range" samples required before recovery
#define VinMeasurementTime			10		// fault handler frequency filter

#endif	/* SYSTEM_PROPERTIES_H */
